"""Denes Router Classifier - BERT-based domain classifier for chatbot routing.

This package provides a lightweight, CPU-optimized BERT classifier to route
user queries in the Denes chatbot system to the appropriate domain handler:

- Web_Search: Explicit search requests (requires Tavily API)
- TI: Technical support queries (internal routing)
- Generic: General knowledge questions (LLM-answerable)

Main API:
    classify_domain(text, threshold, multi_label) -> ClassificationResult

Example:
    >>> from denes_router_classifier import classify_domain
    >>> result = classify_domain("Busca el clima en Asunción")
    >>> result.primary
    'Web_Search'
    >>> result.confidence
    0.9984
"""

__version__ = "0.1.0"

from .classifier import classify_domain, classify_batch
from .schemas import ClassificationResult, PredictionDetail
from .model_loader import is_model_loaded, unload_model, get_model_info

__all__ = [
    # Main API
    "classify_domain",
    "classify_batch",
    # Schemas
    "ClassificationResult",
    "PredictionDetail",
    # Utilities
    "is_model_loaded",
    "unload_model",
    "get_model_info",
    # Metadata
    "__version__",
]
